@@ -32,7 +32,7 @@ from omnata_plugin_runtime.omnata_plugin import (
 from pydantic import parse_obj_as  # pylint: disable=no-name-in-module
 import pydantic.json  # pylint:disable=no-name-in-module
 from slugify import slugify
-from snowcli import config
+from snowcli.snow_connector import connect_to_snowflake
 from snowflake.snowpark import Session
 from tabulate import tabulate
 
@@ -158,7 +158,8 @@ class DevelopmentSession:
             results_table_name="",
             plugin_instance=self.plugin_instance,
             api_limits=self.api_limits,
-            rate_limit_state={},
+            rate_limit_state_all={},
+            rate_limit_state_this_sync_and_branch={},
             run_deadline=None,
             development_mode=True,
         )
@@ -189,11 +190,9 @@ class DevelopmentSession:
         if not click.globals.get_current_context(silent=True):
             # set an empty one so snowcli's app config doesn't error
             click.globals.push_context(click.core.Context(click.core.Group()))
-        snowflake_connector = config.connect_to_snowflake(
-            connection_name=snowcli_environment
-        )
+        snowflake_connection = connect_to_snowflake(connection_name=snowcli_environment)
         builder = Session.builder
-        builder._options["connection"] = snowflake_connector.ctx
+        builder._options["connection"] = snowflake_connection.ctx
         self.session: Session = builder.create()
         self.sync_slug = sync_slug
         session_run_response = self.session.sql(
@@ -283,7 +282,8 @@ class DevelopmentSession:
             records_table_name=outbound_payload.records_table_name,
             plugin_instance=self.plugin_instance,
             api_limits=self.api_limits,
-            rate_limit_state={},
+            rate_limit_state_all={},
+            rate_limit_state_this_sync_and_branch={},
             run_deadline=datetime.datetime.now() + datetime.timedelta(hours=4),
             development_mode=True,
         )
@@ -317,11 +317,9 @@ class DevelopmentSession:
         if not click.globals.get_current_context(silent=True):
             # set an empty one so snowcli's app config doesn't error
             click.globals.push_context(click.core.Context(click.core.Group()))
-        snowflake_connector = config.connect_to_snowflake(
-            connection_name=snowcli_environment
-        )
+        snowflake_connection = connect_to_snowflake(connection_name=snowcli_environment)
         builder = Session.builder
-        builder._options["connection"] = snowflake_connector.ctx
+        builder._options["connection"] = snowflake_connection.ctx
         self.session: Session = builder.create()
         self.sync_slug = sync_slug
         session_run_response = self.session.sql(
@@ -410,7 +408,8 @@ class DevelopmentSession:
             results_table_name=inbound_payload.results_table_name,
             plugin_instance=self.plugin_instance,
             api_limits=self.api_limits,
-            rate_limit_state={},
+            rate_limit_state_all={},
+            rate_limit_state_this_sync_and_branch={},
             run_deadline=datetime.datetime.now() + datetime.timedelta(hours=4),
             development_mode=True,
             # this skips over the part where we check for new streams etc,
@@ -763,6 +762,10 @@ class DevelopmentSession:
                         )
                     else:
                         f.write(f"\t\t\t| {stream.stream_name} | {{}} | \n")
+            if len(self.vcr_filter_query_parameters) > 0:
+                f.write(
+                    f"\t\And when matching requests, we ignore query parameters {','.join(self.vcr_filter_query_parameters)}\n"
+                )
             f.write(
                 f"\t\tAnd we use the HTTP recordings from {recorded_scenario.scenario_cassette_file_name}\n"
             )
