@@ -61,6 +61,7 @@ class PluginUploader:
         plugin_runtime_version: str,
         database_name: Optional[str] = None,
         schema_name: str = "PLUGIN",
+        plugin_tier: str = "byo",
     ):
         # convert icon_source to a base64 string
         if icon_source:
@@ -81,6 +82,7 @@ class PluginUploader:
             has_custom_validator=has_custom_validator,
             plugin_runtime_version=plugin_runtime_version,
             package_source="function",
+            tier=plugin_tier
         )
         return f"""CREATE OR REPLACE FUNCTION {f"{database_name}." if database_name else ''}{schema_name}.OMNATA_PLUGIN_INFO()
   RETURNS OBJECT
@@ -98,6 +100,7 @@ class PluginUploader:
         stage_name: str,
         schema_name: Optional[str] = None,
         is_airbyte: bool = False,
+        partner_plugin: bool = False,
     ) -> str:
         """
         Creates a stage and uploads the latest plugin artifacts, Omnata runtime etc.
@@ -121,6 +124,7 @@ class PluginUploader:
         Any time there are new secrets or external access integrations, Omnata will call CONFIGURE_APIS to update
         all the procs.
         """
+        print(f"Uploading plugin from directory: {plugin_directory}")
         plugin_class: typing.Type[OmnataPlugin]
         plugin_module_file = f"{PLUGIN_MODULE}.py"
         if is_airbyte:
@@ -147,14 +151,16 @@ class PluginUploader:
 
         if not os.path.exists(os.path.join(plugin_directory, plugin_module_file)):
             raise ValueError(f"File not found: {plugin_module_file}")
-        tier_file = Path(os.path.join(plugin_directory, "tier.txt"))
-        plugin_tier: Literal["byo", "standard", "premium"] = (
-            tier_file.read_text(encoding="utf-8").strip()
-            if tier_file.exists()
-            else "byo"
-        )
-        if plugin_tier not in ["standard", "premium", "byo"]:
-            raise ValueError(f"Invalid tier {plugin_tier} in {tier_file}")
+        plugin_tier: Literal["byo","free","standard","premium","partner"] = 'byo' # default
+        if partner_plugin:
+            plugin_tier = 'partner'
+        else:
+            tier_file = Path(os.path.join(plugin_directory, "tier.txt"))
+            if tier_file.exists():
+                plugin_tier = tier_file.read_text(encoding="utf-8").strip()
+                if plugin_tier not in ["standard","premium","byo","free"]:
+                    raise ValueError(f"Invalid tier {plugin_tier} in {tier_file}")
+        print(f"Using plugin tier: {plugin_tier}")
         license_url_file = Path(os.path.join(plugin_directory, "license_url.txt"))
         license_url: Optional[str] = (
             license_url_file.read_text(encoding="utf-8").strip()
@@ -214,8 +220,6 @@ class PluginUploader:
             shutil.rmtree(".packages")
         if os.path.exists("app.zip"):
             os.remove("app.zip")
-        if os.path.exists("app-prerelease.zip"):
-            os.remove("app-prerelease.zip")
 
         print("Creating Snowpark package for Snowflake")
         snowpark_package(
@@ -288,22 +292,9 @@ class PluginUploader:
             setup_script.write(
                 """create table if not exists DATA.OMNATA_REGISTRATION(
                                                 APPLICATION_NAME varchar,
-                                                EXTERNAL_ACCESS_INTEGRATION_NAMES object,
+                                                EXTERNAL_ACCESS_INTEGRATIONS object,
                                                 EXTERNAL_ACCESS_INTEGRATIONS_APPLIED object);\n"""
             )
-            #setup_script.write(
-            #    """alter table DATA.OMNATA_REGISTRATION add column if not exists
-            #            OAUTH_SECRETS ARRAY;\n
-            #    BEGIN
-            #        alter table DATA.OMNATA_REGISTRATION rename column if exists
-            #            SECRETS to OTHER_SECRETS;\n
-            #    EXCEPTION
-            #        -- ignore the rename error
-            #        when other then
-            #        select 1;
-            #    END;
-            #    """
-            #)
             setup_script.write(
                 """
                 alter table DATA.OMNATA_REGISTRATION add column if not exists
@@ -335,15 +326,32 @@ class PluginUploader:
                     )
                     on 1=1
                     when matched then update set EXTERNAL_ACCESS_INTEGRATIONS = NEW_INTEGRATIONS;\n
-                
+                EXCEPTION
+                    -- ignore the drop error
+                    when other then
+                    select 1;
+                END;
+                BEGIN
                     alter table DATA.OMNATA_REGISTRATION drop column EXTERNAL_ACCESS_INTEGRATION_NAMES;\n
-                    alter table DATA.OMNATA_REGISTRATION drop column OAUTH_SECRETS;\n
+                EXCEPTION
+                    -- ignore the drop error
+                    when other then
+                    select 1;
+                END;
+                BEGIN
                     alter table DATA.OMNATA_REGISTRATION drop column OTHER_SECRETS;\n
                 EXCEPTION
                     -- ignore the drop error
                     when other then
                     select 1;
                 END;
+                BEGIN
+                    alter table DATA.OMNATA_REGISTRATION drop column OAUTH_SECRETS;\n
+                EXCEPTION
+                    -- ignore the drop error
+                    when other then
+                    select 1;
+                END;
                 """
             )
             setup_script.write(
@@ -368,6 +376,7 @@ class PluginUploader:
                     plugin_class_name=plugin_class_name,
                     has_custom_validator=has_custom_validator,
                     plugin_runtime_version=omnata_plugin_runtime_version,
+                    plugin_tier=plugin_tier
                 )
             )
             setup_script.write(
@@ -382,10 +391,14 @@ class PluginUploader:
                 "CONFIGURATION_FORM",
                 "CONNECTION_TEST",
                 "CONNECTION_FORM",
+                "CONSTRUCT_FORM_OPTION",
+                "INBOUND_LIST_STREAMS",
                 "CREATE_BILLING_EVENTS",
                 "NETWORK_ADDRESSES",
                 "RETRIEVE_SECRETS",
                 "OUTBOUND_RECORD_VALIDATOR",
+                "TEST_OAUTH_TOKEN_EXISTS",
+                "UPDATE_GENERIC_SECRET_OBJECT"
             ]:
                 template = environment.get_template(f"{proc_template}.sql.jinja")
                 content = template.render(
@@ -404,9 +417,12 @@ class PluginUploader:
                 "PENDING_API_CONFIGURATION",
                 "TEST_CALLBACK",
                 "CREATE_GENERIC_SECRET_OBJECT",
-                "UPDATE_GENERIC_SECRET_OBJECT",
+                "UPDATE_GENERIC_SECRET_OBJECT_OLD",
+                "CREATE_OAUTH_SECRET_OBJECT",
                 "CREATE_NETWORK_RULE_OBJECT",
-                "UPDATE_NETWORK_RULE_OBJECT"
+                "UPDATE_NETWORK_RULE_OBJECT",
+                "RETRIEVE_NETWORK_RULE_OBJECT",
+                "POST_INSTALL_ACTIONS"
             ]:
                 template = environment.get_template(f"{proc_template}.sql.jinja")
                 content = template.render({})
@@ -455,15 +471,13 @@ class PluginUploader:
 
             # in rare cases, the plugin author might want to do something of their own in the setup script
             # so we allow them to create a file called setup_script.sql and we'll append it to the end of the script
-            if os.path.exists("setup_script.sql"):
-                print("Adding custom setup script")
+            custom_setup_script = os.path.join(plugin_directory, "custom_setup_script.sql")
+            if os.path.exists(custom_setup_script):
+                print("Adding custom setup script contents")
                 with open(
-                    "setup_script.sql", "r", encoding="utf-8"
+                    custom_setup_script, "r", encoding="utf-8"
                 ) as custom_setup_script:
                     setup_script.write(custom_setup_script.read() + "\n")
-            template = environment.get_template(f"{proc_template}.sql.jinja")
-            content = template.render({})
-            setup_script.write(f"{content}\n")
 
             # Upload the configuration streamlit
             setup_script.write("create or alter versioned schema UI;\n")
@@ -477,8 +491,9 @@ MAIN_FILE = '/plugin_configuration.py';"""
             )
 
             setup_script.write(
-                """GRANT USAGE ON STREAMLIT UI."Plugin Configuration" TO application role OMNATA_MANAGEMENT;"""
+                """GRANT USAGE ON STREAMLIT UI."Plugin Configuration" TO application role OMNATA_MANAGEMENT;\n"""
             )
+            setup_script.write("call PLUGIN.POST_INSTALL_ACTIONS();\n")
 
         print("Uploading plugin streamlit to stage")
         with open(
@@ -555,14 +570,9 @@ MAIN_FILE = '/plugin_configuration.py';"""
                     plugin_runtime_version=omnata_plugin_runtime_version,
                     database_name=os.environ["OMNATA_LATEST_PLUGIN_INFO_DATABASE"],
                     schema_name=os.environ["OMNATA_LATEST_PLUGIN_INFO_SCHEMA"],
+                    plugin_tier=plugin_tier
                 )
             ).collect()
-
-        # print('Registering app')
-        # TODO: grant access to the role which owns the omnata app
-        # self.session.sql(f"GRANT USAGE ON DATABASE {database_name} TO ROLE INTEGRATION_TEST_ROLE").collect()
-        # self.session.sql(f"GRANT USAGE ON SCHEMA {database_name}.{schema_name} TO ROLE INTEGRATION_TEST_ROLE").collect()
-        # self.session.sql(f"GRANT READ ON STAGE {database_name}.{schema_name}.PLUGIN_IMPORTS TO ROLE INTEGRATION_TEST_ROLE").collect()
         return schema_name
 
 
